# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import datetime
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='VisitData',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('visit_date', models.DateField(verbose_name='Data wizyty')),
                ('guest', models.CharField(max_length=150, verbose_name='Imi\u0119 i nazwisko go\u015bcia')),
                ('company', models.CharField(max_length=150, verbose_name='Firma kt\xf3r\u0105 reprezentuje', blank=True)),
                ('visit_host', models.CharField(max_length=150, verbose_name='Do kogo')),
                ('plan_hour', models.TimeField(default=datetime.time(0, 0), verbose_name='Planowana godzina wizyty')),
                ('arrive_hour', models.TimeField(null=True, verbose_name='Godzina przybycia', blank=True)),
                ('exit_hour', models.TimeField(null=True, verbose_name='Godzina wyj\u015bcia', blank=True)),
                ('coffe', models.NullBooleanField(verbose_name='Kawa')),
                ('lunch', models.NullBooleanField(verbose_name='Lunch')),
                ('comment', models.TextField(max_length=250, verbose_name='Komentarz', blank=True)),
                ('key_in_user', models.ForeignKey(verbose_name='U\u017cytkownik', to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]



#coding: utf-8
from __future__ import unicode_literals, absolute_import, print_function

import django_filters

from .models import VisitData

class DataFilter(django_filters.FilterSet):
    class Meta:
        model = VisitData
        fields = ['visit_date',]



#coding: utf-8
from __future__ import unicode_literals, absolute_import, print_function

import datetime

from django.contrib.auth.models import User
from django.db import models

# Create your models here.
class VisitData(models.Model):
    visit_date = models.DateField(verbose_name="Data wizyty")
    guest = models.CharField(verbose_name="Imię i nazwisko gościa", max_length=150 )
    company = models.CharField(verbose_name="Firma którą reprezentuje", blank=True, max_length=150)
    visit_host = models.CharField(verbose_name="Do kogo", max_length=150)
    plan_hour = models.TimeField(verbose_name="Planowana godzina wizyty",default=datetime.time(00, 00))
    arrive_hour = models.TimeField(verbose_name="Godzina przybycia", null=True, blank=True)
    exit_hour = models.TimeField(verbose_name="Godzina wyjścia", null=True, blank=True)
    coffe = models.NullBooleanField(verbose_name="Kawa")
    lunch = models.NullBooleanField(verbose_name="Lunch")
    comment = models.TextField(verbose_name="Komentarz", max_length=250, blank=True)
    key_in_user = models.ForeignKey(User, verbose_name="Użytkownik")



#coding: utf-8
from __future__ import unicode_literals, absolute_import, print_function

from django import forms

from .models import VisitData
#from django.contrib.auth.models import User
from .models import User
import re
from django.core.exceptions import ObjectDoesNotExist

forms.DateInput.input_type="date"
forms.DateInput.input_formats="'%Y-%m-%d'"
forms.DateTimeInput.input_type="datetime-local"
forms.TimeInput.input_type="time"


class VisitCreateForm(forms.ModelForm):

    class Meta:
        model = VisitData
        exclude = ['arrive_hour','exit_hour','key_in_user']


class RegisterForm(forms.Form):
    username = forms.CharField(label="Login:", max_length=30)
    email = forms.EmailField(label="Email:", required=False)
    password1 = forms.CharField(label="Hasło:", widget=forms.PasswordInput())
    password2 = forms.CharField(label="Powtórz hasło:", widget=forms.PasswordInput())
    first_name = forms.CharField(label="Imię:",max_length=20, required=False)
    last_name = forms.CharField(label="Nazwisko:",max_length=30, required=False)
    log_on = forms.BooleanField(label="Logowanie po rejestracji:", required=False)

    def clean_password2(self):
        password1=self.cleaned_data['password1']
        password2=self.cleaned_data['password2']
        if password1==password2:
            return password2
        else:
            raise forms.ValidationError("Hasła się różnią")

    def clean_username(self):
        username = self.cleaned_data['username']
        if not re.search(r'^\w+$',username):
            raise forms.ValidationError("Dopuszczalne są tylko cyfry, litery angielskie i _")
        try:
            User.objects.get(username=username)
        except ObjectDoesNotExist:
            return username
        raise forms.ValidationError("Taki użytkownik już istnieje")





"""gatehouse URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/1.8/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  url(r'^$', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  url(r'^$', Home.as_view(), name='home')
Including another URLconf
    1. Add a URL to urlpatterns:  url(r'^blog/', include('blog.urls'))
"""
from django.conf.urls import include, url
from django.contrib import admin
from django.contrib.auth import views as auth_views
from django.contrib.auth.decorators import login_required

import gatehouseapp.views

urlpatterns = [
    url(r'^admin/', include(admin.site.urls)),
    url(r'^accounts/login/$', auth_views.login, name='login'),
    url(r'^accounts/logout/$', auth_views.logout, {'next_page': '/'}, name='logout'),
    url(r'^$', gatehouseapp.views.homePage, name='home'),
    url(r'^gatehouseadmin/$', gatehouseapp.views.addVisit, name='appadmin'),
    url(r'^gatehousearch/$', gatehouseapp.views.archive, name='arch'),
    url(r'^delete/(?P<pk>\d+)$', login_required(gatehouseapp.views.VisitDelete.as_view()), name='delete'),
    url(r'^update/(?P<pk>\d+)$', login_required(gatehouseapp.views.UpdateVisitData.as_view()), name='update'),
    url(r'^todayvisit/$', login_required(gatehouseapp.views.TodayVisitForGatehouePersonListView.as_view()), name='todayvisit'),
    url(r'^updatearrive/(?P<pk>\d+)$', login_required(gatehouseapp.views.UpdateArriveHour.as_view()), name='update_arrive_hour'),
    url(r'^updateexit/(?P<pk>\d+)$', login_required(gatehouseapp.views.UpdateExitHour.as_view()), name='update_exit_hour'),
    url(r'^catering', login_required(gatehouseapp.views.CateringListView.as_view()), name='cateringurl'),
]



#coding: utf-8
from __future__ import unicode_literals, absolute_import, print_function

import datetime

from django.contrib.auth.decorators import login_required
from django.core.paginator import Paginator, PageNotAnInteger, EmptyPage
from django.core.urlresolvers import reverse, reverse_lazy
from django.db.models import Q
from django.http import HttpResponseRedirect
from django.shortcuts import render
from django.views.generic import ListView
from django.views.generic.edit import UpdateView, DeleteView

from .filters import DataFilter
from .forms import VisitCreateForm
from .models import VisitData
# Create your views here.
def homePage(request):
    return render(request, 'gatehouseapp/index.html')


def pagination(strona, zmienna):
    paginator = Paginator(zmienna, 10)
    try:
        page_filter = paginator.page(strona)
    except PageNotAnInteger:
        page_filter = paginator.page(1)
    except EmptyPage:
        page_filter = paginator.page(paginator.num_pages)
    return page_filter


@login_required(login_url='accounts/login/')
def addVisit(request):
    form = VisitCreateForm()
    visit_details = DataFilter(request.GET, queryset=VisitData.objects.filter(visit_date=datetime.date.today()).order_by('plan_hour'))
    page = request.GET.get('page')
    page_filter = pagination(page, visit_details)
    if request.method == 'POST':
        if '_add' in request.POST:
            form = VisitCreateForm(request.POST)
            if form.is_valid():
                entry = form.save(commit=False)
                entry.key_in_user = request.user
                entry.save()
                return HttpResponseRedirect(reverse('appadmin'))
        elif '_today' in request.POST:
            visit_details = DataFilter(request.GET, queryset=VisitData.objects.filter(visit_date=datetime.date.today()).order_by('plan_hour'))
            page_filter = pagination(page, visit_details)
        elif '_tomorrow' in request.POST:
            visit_details = DataFilter(request.GET, queryset=VisitData.objects.filter(visit_date__gte = datetime.date.today()+datetime.timedelta(1)).order_by('plan_hour'))
            page_filter = pagination(page, visit_details)
        elif '_arch' in request.POST:
            return HttpResponseRedirect(reverse('arch'))
    return render(request, 'gatehouseapp/addvisit.html',
        {'form': form, 'page_filter': page_filter})


class UpdateVisitData(UpdateView):
    model = VisitData
    fields = ['visit_date','guest','company','visit_host','plan_hour','coffe','lunch','comment' ]
    template_name = "gatehouseapp/update.html"
    success_url = reverse_lazy('appadmin')


@login_required(login_url='accounts/login/')
def archive(request):
    form = VisitCreateForm()
    visit_details = DataFilter(request.GET, queryset=VisitData.objects.all().exclude(visit_date__gte = datetime.date.today()-datetime.timedelta(1)).order_by('plan_hour'))
    page = request.GET.get('page')
    page_filter = pagination(page, visit_details)
    if request.method == 'POST':
        if '_today' in request.POST:
            return HttpResponseRedirect(reverse('appadmin'))
    return render(request,'gatehouseapp/arch.html', {'form': form, 'page_filter': page_filter, 'filter': visit_details,})


class TodayVisitForGatehouePersonListView(ListView):
    model = VisitData
    context_object_name = 'page_filter'
    template_name ='gatehouseapp/todaygatehousepersonlist.html'

    def get_queryset(self):
        return VisitData.objects.filter(visit_date=datetime.date.today())


class UpdateArriveHour(UpdateView):
    model = VisitData
    fields = ['arrive_hour',]
    template_name = "gatehouseapp/update.html"
    success_url = reverse_lazy('todayvisit')


class UpdateExitHour(UpdateView):
    model = VisitData
    fields = ['exit_hour',]
    template_name = "gatehouseapp/update.html"
    success_url = reverse_lazy('todayvisit')


class CateringListView(ListView):
    model = VisitData
    context_object_name = 'page_filter'
    template_name = 'gatehouseapp/catering.html'

    def get_queryset(self):
        return VisitData.objects.filter(Q(lunch=True, visit_date=datetime.date.today()) | Q(coffe=True, visit_date=datetime.date.today()))


class VisitDelete(DeleteView):
    model = VisitData
    template_name = "gatehouseapp/delete.html"
    success_url = reverse_lazy('appadmin')
